about summary refs log tree commit diff
path: root/youtube_dl/extractor/common.py
diff options
context:
space:
mode:
authorSergey M․ <dstftw@gmail.com>2019-03-05 00:39:15 +0700
committerSergey M․ <dstftw@gmail.com>2019-03-05 00:41:53 +0700
commitc790e93ab5db5f318fb094b8a45f9160cdf4bd9b (patch)
treed0ed706eb8b54a4f01a4162c5b574255e7e7e552 /youtube_dl/extractor/common.py
parent39c780fdec2c62135f37e3565efedf7dcad605ba (diff)
downloadyoutube-dl-c790e93ab5db5f318fb094b8a45f9160cdf4bd9b.tar.gz
youtube-dl-c790e93ab5db5f318fb094b8a45f9160cdf4bd9b.tar.xz
youtube-dl-c790e93ab5db5f318fb094b8a45f9160cdf4bd9b.zip
[extractor/common] Clarify url and manifest_url meta fields
Diffstat (limited to 'youtube_dl/extractor/common.py')
-rw-r--r--youtube_dl/extractor/common.py14
1 files changed, 12 insertions, 2 deletions
diff --git a/youtube_dl/extractor/common.py b/youtube_dl/extractor/common.py
index 1fa8048b8..641e50f3c 100644
--- a/youtube_dl/extractor/common.py
+++ b/youtube_dl/extractor/common.py
@@ -102,10 +102,20 @@ class InfoExtractor(object):
                     from worst to best quality.
 
                     Potential fields:
-                    * url        Mandatory. The URL of the video file
+                    * url        The mandatory URL representing the media:
+                                   for plain file media - HTTP URL of this file,
+                                   for RTMP - RTMP URL,
+                                   for HLS - URL of the M3U8 media playlist,
+                                   for HDS - URL of the F4M manifest,
+                                   for DASH - URL of the MPD manifest,
+                                   for MSS - URL of the ISM manifest.
                     * manifest_url
                                  The URL of the manifest file in case of
-                                 fragmented media (DASH, hls, hds)
+                                 fragmented media:
+                                   for HLS - URL of the M3U8 master playlist,
+                                   for HDS - URL of the F4M manifest,
+                                   for DASH - URL of the MPD manifest,
+                                   for MSS - URL of the ISM manifest.
                     * ext        Will be calculated from URL if missing
                     * format     A human-readable description of the format
                                  ("mp4 container with h264/opus").